__version__ = "0.2.9"
__author__ = "David Li <davidli012345@gmail.com>"
# from cad_tickers.exchanges import *